@@ -8,6 +8,7 @@
 
 //Okay, let's import our internal modules
 pub mod cstdlib;
+pub mod errno;
 pub mod posix_types;
 pub mod time;
 
@@ -17,12 +18,38 @@ pub use std::os::linux::raw::*; //Needed for time_t, dev_t, etc
 
 //And re-export our modules
 pub use cstdlib::*;
+pub use errno::*;
 pub use posix_types::*;
 pub use time::*;
 
+extern {
+
+    //pub fn syscall(num: ::c_long, ...) -> ::c_int; TODO: Check this, exit() does not work via syscall. Check branch `unistd-syscall-rewrite`
+    
+    ///Gets the pointer of the last error number's location
+    pub fn __errno_location() -> *mut ::c_int;
+
+}
+
+///Gets the last error number
+pub fn get_last_error_number() -> ::c_int {
+        
+    unsafe {
+        let pointer = __errno_location();
+        
+        return ::std::ptr::read(pointer);
+    }
+    
+}
+
 #[cfg(test)]
 mod tests {
 
+    #[test]
+    fn no_errors_means_no_stupid_error() {
+        assert_eq!(0, ::get_last_error_number());
+    }
+
     #[allow(unused_variables)]
     #[test]
     fn ensure_types_exist() {
